Documentation
¶
Overview ¶
Package v1 is a reverse proxy.
It translates gRPC into RESTful JSON APIs.
Index ¶
- Variables
- func RegisterProvisioningServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterProvisioningServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client ProvisioningServiceClient) error
- func RegisterProvisioningServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, ...) (err error)
- func RegisterProvisioningServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server ProvisioningServiceServer) error
- func RegisterProvisioningServiceServer(s grpc.ServiceRegistrar, srv ProvisioningServiceServer)
- type CloudConfig
- func (*CloudConfig) Descriptor() ([]byte, []int)deprecated
- func (x *CloudConfig) GetAppAddress() string
- func (x *CloudConfig) GetId() string
- func (x *CloudConfig) GetSecret() string
- func (*CloudConfig) ProtoMessage()
- func (x *CloudConfig) ProtoReflect() protoreflect.Message
- func (x *CloudConfig) Reset()
- func (x *CloudConfig) String() string
- type GetNetworkListRequest
- type GetNetworkListResponse
- func (*GetNetworkListResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetNetworkListResponse) GetNetworks() []*NetworkInfo
- func (*GetNetworkListResponse) ProtoMessage()
- func (x *GetNetworkListResponse) ProtoReflect() protoreflect.Message
- func (x *GetNetworkListResponse) Reset()
- func (x *GetNetworkListResponse) String() string
- type GetSmartMachineStatusRequest
- func (*GetSmartMachineStatusRequest) Descriptor() ([]byte, []int)deprecated
- func (*GetSmartMachineStatusRequest) ProtoMessage()
- func (x *GetSmartMachineStatusRequest) ProtoReflect() protoreflect.Message
- func (x *GetSmartMachineStatusRequest) Reset()
- func (x *GetSmartMachineStatusRequest) String() string
- type GetSmartMachineStatusResponse
- func (*GetSmartMachineStatusResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetSmartMachineStatusResponse) GetErrors() []string
- func (x *GetSmartMachineStatusResponse) GetHasSmartMachineCredentials() bool
- func (x *GetSmartMachineStatusResponse) GetIsOnline() bool
- func (x *GetSmartMachineStatusResponse) GetLatestConnectionAttempt() *NetworkInfo
- func (x *GetSmartMachineStatusResponse) GetProvisioningInfo() *ProvisioningInfo
- func (*GetSmartMachineStatusResponse) ProtoMessage()
- func (x *GetSmartMachineStatusResponse) ProtoReflect() protoreflect.Message
- func (x *GetSmartMachineStatusResponse) Reset()
- func (x *GetSmartMachineStatusResponse) String() string
- type NetworkInfo
- func (*NetworkInfo) Descriptor() ([]byte, []int)deprecated
- func (x *NetworkInfo) GetConnected() bool
- func (x *NetworkInfo) GetLastError() string
- func (x *NetworkInfo) GetSecurity() string
- func (x *NetworkInfo) GetSignal() int32
- func (x *NetworkInfo) GetSsid() string
- func (x *NetworkInfo) GetType() string
- func (*NetworkInfo) ProtoMessage()
- func (x *NetworkInfo) ProtoReflect() protoreflect.Message
- func (x *NetworkInfo) Reset()
- func (x *NetworkInfo) String() string
- type ProvisioningInfo
- func (*ProvisioningInfo) Descriptor() ([]byte, []int)deprecated
- func (x *ProvisioningInfo) GetFragmentId() string
- func (x *ProvisioningInfo) GetManufacturer() string
- func (x *ProvisioningInfo) GetModel() string
- func (*ProvisioningInfo) ProtoMessage()
- func (x *ProvisioningInfo) ProtoReflect() protoreflect.Message
- func (x *ProvisioningInfo) Reset()
- func (x *ProvisioningInfo) String() string
- type ProvisioningServiceClient
- type ProvisioningServiceServer
- type SetNetworkCredentialsRequest
- func (*SetNetworkCredentialsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SetNetworkCredentialsRequest) GetPsk() string
- func (x *SetNetworkCredentialsRequest) GetSsid() string
- func (x *SetNetworkCredentialsRequest) GetType() string
- func (*SetNetworkCredentialsRequest) ProtoMessage()
- func (x *SetNetworkCredentialsRequest) ProtoReflect() protoreflect.Message
- func (x *SetNetworkCredentialsRequest) Reset()
- func (x *SetNetworkCredentialsRequest) String() string
- type SetNetworkCredentialsResponse
- func (*SetNetworkCredentialsResponse) Descriptor() ([]byte, []int)deprecated
- func (*SetNetworkCredentialsResponse) ProtoMessage()
- func (x *SetNetworkCredentialsResponse) ProtoReflect() protoreflect.Message
- func (x *SetNetworkCredentialsResponse) Reset()
- func (x *SetNetworkCredentialsResponse) String() string
- type SetSmartMachineCredentialsRequest
- func (*SetSmartMachineCredentialsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SetSmartMachineCredentialsRequest) GetCloud() *CloudConfig
- func (*SetSmartMachineCredentialsRequest) ProtoMessage()
- func (x *SetSmartMachineCredentialsRequest) ProtoReflect() protoreflect.Message
- func (x *SetSmartMachineCredentialsRequest) Reset()
- func (x *SetSmartMachineCredentialsRequest) String() string
- type SetSmartMachineCredentialsResponse
- func (*SetSmartMachineCredentialsResponse) Descriptor() ([]byte, []int)deprecated
- func (*SetSmartMachineCredentialsResponse) ProtoMessage()
- func (x *SetSmartMachineCredentialsResponse) ProtoReflect() protoreflect.Message
- func (x *SetSmartMachineCredentialsResponse) Reset()
- func (x *SetSmartMachineCredentialsResponse) String() string
- type UnimplementedProvisioningServiceServer
- func (UnimplementedProvisioningServiceServer) GetNetworkList(context.Context, *GetNetworkListRequest) (*GetNetworkListResponse, error)
- func (UnimplementedProvisioningServiceServer) GetSmartMachineStatus(context.Context, *GetSmartMachineStatusRequest) (*GetSmartMachineStatusResponse, error)
- func (UnimplementedProvisioningServiceServer) SetNetworkCredentials(context.Context, *SetNetworkCredentialsRequest) (*SetNetworkCredentialsResponse, error)
- func (UnimplementedProvisioningServiceServer) SetSmartMachineCredentials(context.Context, *SetSmartMachineCredentialsRequest) (*SetSmartMachineCredentialsResponse, error)
- type UnsafeProvisioningServiceServer
Constants ¶
This section is empty.
Variables ¶
var File_provisioning_v1_provisioning_proto protoreflect.FileDescriptor
var ProvisioningService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "viam.provisioning.v1.ProvisioningService", HandlerType: (*ProvisioningServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "GetSmartMachineStatus", Handler: _ProvisioningService_GetSmartMachineStatus_Handler, }, { MethodName: "SetNetworkCredentials", Handler: _ProvisioningService_SetNetworkCredentials_Handler, }, { MethodName: "SetSmartMachineCredentials", Handler: _ProvisioningService_SetSmartMachineCredentials_Handler, }, { MethodName: "GetNetworkList", Handler: _ProvisioningService_GetNetworkList_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "provisioning/v1/provisioning.proto", }
ProvisioningService_ServiceDesc is the grpc.ServiceDesc for ProvisioningService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterProvisioningServiceHandler ¶
func RegisterProvisioningServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterProvisioningServiceHandler registers the http handlers for service ProvisioningService to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterProvisioningServiceHandlerClient ¶
func RegisterProvisioningServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client ProvisioningServiceClient) error
RegisterProvisioningServiceHandlerClient registers the http handlers for service ProvisioningService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "ProvisioningServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "ProvisioningServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "ProvisioningServiceClient" to call the correct interceptors.
func RegisterProvisioningServiceHandlerFromEndpoint ¶
func RegisterProvisioningServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterProvisioningServiceHandlerFromEndpoint is same as RegisterProvisioningServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterProvisioningServiceHandlerServer ¶
func RegisterProvisioningServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server ProvisioningServiceServer) error
RegisterProvisioningServiceHandlerServer registers the http handlers for service ProvisioningService to "mux". UnaryRPC :call ProvisioningServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterProvisioningServiceHandlerFromEndpoint instead.
func RegisterProvisioningServiceServer ¶
func RegisterProvisioningServiceServer(s grpc.ServiceRegistrar, srv ProvisioningServiceServer)
Types ¶
type CloudConfig ¶
type CloudConfig struct {
// SmartMachine part id
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// SmartMachine part secret
Secret string `protobuf:"bytes,2,opt,name=secret,proto3" json:"secret,omitempty"`
AppAddress string `protobuf:"bytes,3,opt,name=app_address,json=appAddress,proto3" json:"app_address,omitempty"`
// contains filtered or unexported fields
}
minimal CloudConfig to create /etc/viam.json
func (*CloudConfig) Descriptor
deprecated
func (*CloudConfig) Descriptor() ([]byte, []int)
Deprecated: Use CloudConfig.ProtoReflect.Descriptor instead.
func (*CloudConfig) GetAppAddress ¶
func (x *CloudConfig) GetAppAddress() string
func (*CloudConfig) GetId ¶
func (x *CloudConfig) GetId() string
func (*CloudConfig) GetSecret ¶
func (x *CloudConfig) GetSecret() string
func (*CloudConfig) ProtoMessage ¶
func (*CloudConfig) ProtoMessage()
func (*CloudConfig) ProtoReflect ¶
func (x *CloudConfig) ProtoReflect() protoreflect.Message
func (*CloudConfig) Reset ¶
func (x *CloudConfig) Reset()
func (*CloudConfig) String ¶
func (x *CloudConfig) String() string
type GetNetworkListRequest ¶
type GetNetworkListRequest struct {
// contains filtered or unexported fields
}
func (*GetNetworkListRequest) Descriptor
deprecated
func (*GetNetworkListRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetNetworkListRequest.ProtoReflect.Descriptor instead.
func (*GetNetworkListRequest) ProtoMessage ¶
func (*GetNetworkListRequest) ProtoMessage()
func (*GetNetworkListRequest) ProtoReflect ¶
func (x *GetNetworkListRequest) ProtoReflect() protoreflect.Message
func (*GetNetworkListRequest) Reset ¶
func (x *GetNetworkListRequest) Reset()
func (*GetNetworkListRequest) String ¶
func (x *GetNetworkListRequest) String() string
type GetNetworkListResponse ¶
type GetNetworkListResponse struct {
Networks []*NetworkInfo `protobuf:"bytes,1,rep,name=networks,proto3" json:"networks,omitempty"`
// contains filtered or unexported fields
}
func (*GetNetworkListResponse) Descriptor
deprecated
func (*GetNetworkListResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetNetworkListResponse.ProtoReflect.Descriptor instead.
func (*GetNetworkListResponse) GetNetworks ¶
func (x *GetNetworkListResponse) GetNetworks() []*NetworkInfo
func (*GetNetworkListResponse) ProtoMessage ¶
func (*GetNetworkListResponse) ProtoMessage()
func (*GetNetworkListResponse) ProtoReflect ¶
func (x *GetNetworkListResponse) ProtoReflect() protoreflect.Message
func (*GetNetworkListResponse) Reset ¶
func (x *GetNetworkListResponse) Reset()
func (*GetNetworkListResponse) String ¶
func (x *GetNetworkListResponse) String() string
type GetSmartMachineStatusRequest ¶
type GetSmartMachineStatusRequest struct {
// contains filtered or unexported fields
}
func (*GetSmartMachineStatusRequest) Descriptor
deprecated
func (*GetSmartMachineStatusRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetSmartMachineStatusRequest.ProtoReflect.Descriptor instead.
func (*GetSmartMachineStatusRequest) ProtoMessage ¶
func (*GetSmartMachineStatusRequest) ProtoMessage()
func (*GetSmartMachineStatusRequest) ProtoReflect ¶
func (x *GetSmartMachineStatusRequest) ProtoReflect() protoreflect.Message
func (*GetSmartMachineStatusRequest) Reset ¶
func (x *GetSmartMachineStatusRequest) Reset()
func (*GetSmartMachineStatusRequest) String ¶
func (x *GetSmartMachineStatusRequest) String() string
type GetSmartMachineStatusResponse ¶
type GetSmartMachineStatusResponse struct {
ProvisioningInfo *ProvisioningInfo `protobuf:"bytes,1,opt,name=provisioning_info,json=provisioningInfo,proto3" json:"provisioning_info,omitempty"`
HasSmartMachineCredentials bool `` /* 144-byte string literal not displayed */
IsOnline bool `protobuf:"varint,3,opt,name=is_online,json=isOnline,proto3" json:"is_online,omitempty"`
LatestConnectionAttempt *NetworkInfo `` /* 132-byte string literal not displayed */
Errors []string `protobuf:"bytes,5,rep,name=errors,proto3" json:"errors,omitempty"`
// contains filtered or unexported fields
}
func (*GetSmartMachineStatusResponse) Descriptor
deprecated
func (*GetSmartMachineStatusResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetSmartMachineStatusResponse.ProtoReflect.Descriptor instead.
func (*GetSmartMachineStatusResponse) GetErrors ¶
func (x *GetSmartMachineStatusResponse) GetErrors() []string
func (*GetSmartMachineStatusResponse) GetHasSmartMachineCredentials ¶
func (x *GetSmartMachineStatusResponse) GetHasSmartMachineCredentials() bool
func (*GetSmartMachineStatusResponse) GetIsOnline ¶
func (x *GetSmartMachineStatusResponse) GetIsOnline() bool
func (*GetSmartMachineStatusResponse) GetLatestConnectionAttempt ¶
func (x *GetSmartMachineStatusResponse) GetLatestConnectionAttempt() *NetworkInfo
func (*GetSmartMachineStatusResponse) GetProvisioningInfo ¶
func (x *GetSmartMachineStatusResponse) GetProvisioningInfo() *ProvisioningInfo
func (*GetSmartMachineStatusResponse) ProtoMessage ¶
func (*GetSmartMachineStatusResponse) ProtoMessage()
func (*GetSmartMachineStatusResponse) ProtoReflect ¶
func (x *GetSmartMachineStatusResponse) ProtoReflect() protoreflect.Message
func (*GetSmartMachineStatusResponse) Reset ¶
func (x *GetSmartMachineStatusResponse) Reset()
func (*GetSmartMachineStatusResponse) String ¶
func (x *GetSmartMachineStatusResponse) String() string
type NetworkInfo ¶
type NetworkInfo struct {
Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
Ssid string `protobuf:"bytes,2,opt,name=ssid,proto3" json:"ssid,omitempty"`
Security string `protobuf:"bytes,3,opt,name=security,proto3" json:"security,omitempty"`
Signal int32 `protobuf:"varint,4,opt,name=signal,proto3" json:"signal,omitempty"`
Connected bool `protobuf:"varint,5,opt,name=connected,proto3" json:"connected,omitempty"`
LastError string `protobuf:"bytes,6,opt,name=last_error,json=lastError,proto3" json:"last_error,omitempty"`
// contains filtered or unexported fields
}
func (*NetworkInfo) Descriptor
deprecated
func (*NetworkInfo) Descriptor() ([]byte, []int)
Deprecated: Use NetworkInfo.ProtoReflect.Descriptor instead.
func (*NetworkInfo) GetConnected ¶
func (x *NetworkInfo) GetConnected() bool
func (*NetworkInfo) GetLastError ¶
func (x *NetworkInfo) GetLastError() string
func (*NetworkInfo) GetSecurity ¶
func (x *NetworkInfo) GetSecurity() string
func (*NetworkInfo) GetSignal ¶
func (x *NetworkInfo) GetSignal() int32
func (*NetworkInfo) GetSsid ¶
func (x *NetworkInfo) GetSsid() string
func (*NetworkInfo) GetType ¶
func (x *NetworkInfo) GetType() string
func (*NetworkInfo) ProtoMessage ¶
func (*NetworkInfo) ProtoMessage()
func (*NetworkInfo) ProtoReflect ¶
func (x *NetworkInfo) ProtoReflect() protoreflect.Message
func (*NetworkInfo) Reset ¶
func (x *NetworkInfo) Reset()
func (*NetworkInfo) String ¶
func (x *NetworkInfo) String() string
type ProvisioningInfo ¶
type ProvisioningInfo struct {
FragmentId string `protobuf:"bytes,1,opt,name=fragment_id,json=fragmentId,proto3" json:"fragment_id,omitempty"`
Model string `protobuf:"bytes,2,opt,name=model,proto3" json:"model,omitempty"`
Manufacturer string `protobuf:"bytes,3,opt,name=manufacturer,proto3" json:"manufacturer,omitempty"`
// contains filtered or unexported fields
}
func (*ProvisioningInfo) Descriptor
deprecated
func (*ProvisioningInfo) Descriptor() ([]byte, []int)
Deprecated: Use ProvisioningInfo.ProtoReflect.Descriptor instead.
func (*ProvisioningInfo) GetFragmentId ¶
func (x *ProvisioningInfo) GetFragmentId() string
func (*ProvisioningInfo) GetManufacturer ¶
func (x *ProvisioningInfo) GetManufacturer() string
func (*ProvisioningInfo) GetModel ¶
func (x *ProvisioningInfo) GetModel() string
func (*ProvisioningInfo) ProtoMessage ¶
func (*ProvisioningInfo) ProtoMessage()
func (*ProvisioningInfo) ProtoReflect ¶
func (x *ProvisioningInfo) ProtoReflect() protoreflect.Message
func (*ProvisioningInfo) Reset ¶
func (x *ProvisioningInfo) Reset()
func (*ProvisioningInfo) String ¶
func (x *ProvisioningInfo) String() string
type ProvisioningServiceClient ¶
type ProvisioningServiceClient interface {
// GetSmartMachineStatus is for retrieving the status of the smart machine including networking.
GetSmartMachineStatus(ctx context.Context, in *GetSmartMachineStatusRequest, opts ...grpc.CallOption) (*GetSmartMachineStatusResponse, error)
// SetNetworkCredentials is to set the wifi credentials.
SetNetworkCredentials(ctx context.Context, in *SetNetworkCredentialsRequest, opts ...grpc.CallOption) (*SetNetworkCredentialsResponse, error)
// SetSmartMachineCredentials is to set the smart machine credentials.
SetSmartMachineCredentials(ctx context.Context, in *SetSmartMachineCredentialsRequest, opts ...grpc.CallOption) (*SetSmartMachineCredentialsResponse, error)
// GetNetworkList is to retrieve the list of networks that are visible to the smart machine.
GetNetworkList(ctx context.Context, in *GetNetworkListRequest, opts ...grpc.CallOption) (*GetNetworkListResponse, error)
}
ProvisioningServiceClient is the client API for ProvisioningService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewProvisioningServiceClient ¶
func NewProvisioningServiceClient(cc grpc.ClientConnInterface) ProvisioningServiceClient
type ProvisioningServiceServer ¶
type ProvisioningServiceServer interface {
// GetSmartMachineStatus is for retrieving the status of the smart machine including networking.
GetSmartMachineStatus(context.Context, *GetSmartMachineStatusRequest) (*GetSmartMachineStatusResponse, error)
// SetNetworkCredentials is to set the wifi credentials.
SetNetworkCredentials(context.Context, *SetNetworkCredentialsRequest) (*SetNetworkCredentialsResponse, error)
// SetSmartMachineCredentials is to set the smart machine credentials.
SetSmartMachineCredentials(context.Context, *SetSmartMachineCredentialsRequest) (*SetSmartMachineCredentialsResponse, error)
// GetNetworkList is to retrieve the list of networks that are visible to the smart machine.
GetNetworkList(context.Context, *GetNetworkListRequest) (*GetNetworkListResponse, error)
// contains filtered or unexported methods
}
ProvisioningServiceServer is the server API for ProvisioningService service. All implementations must embed UnimplementedProvisioningServiceServer for forward compatibility
type SetNetworkCredentialsRequest ¶
type SetNetworkCredentialsRequest struct {
Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
Ssid string `protobuf:"bytes,2,opt,name=ssid,proto3" json:"ssid,omitempty"`
Psk string `protobuf:"bytes,3,opt,name=psk,proto3" json:"psk,omitempty"`
// contains filtered or unexported fields
}
func (*SetNetworkCredentialsRequest) Descriptor
deprecated
func (*SetNetworkCredentialsRequest) Descriptor() ([]byte, []int)
Deprecated: Use SetNetworkCredentialsRequest.ProtoReflect.Descriptor instead.
func (*SetNetworkCredentialsRequest) GetPsk ¶
func (x *SetNetworkCredentialsRequest) GetPsk() string
func (*SetNetworkCredentialsRequest) GetSsid ¶
func (x *SetNetworkCredentialsRequest) GetSsid() string
func (*SetNetworkCredentialsRequest) GetType ¶
func (x *SetNetworkCredentialsRequest) GetType() string
func (*SetNetworkCredentialsRequest) ProtoMessage ¶
func (*SetNetworkCredentialsRequest) ProtoMessage()
func (*SetNetworkCredentialsRequest) ProtoReflect ¶
func (x *SetNetworkCredentialsRequest) ProtoReflect() protoreflect.Message
func (*SetNetworkCredentialsRequest) Reset ¶
func (x *SetNetworkCredentialsRequest) Reset()
func (*SetNetworkCredentialsRequest) String ¶
func (x *SetNetworkCredentialsRequest) String() string
type SetNetworkCredentialsResponse ¶
type SetNetworkCredentialsResponse struct {
// contains filtered or unexported fields
}
func (*SetNetworkCredentialsResponse) Descriptor
deprecated
func (*SetNetworkCredentialsResponse) Descriptor() ([]byte, []int)
Deprecated: Use SetNetworkCredentialsResponse.ProtoReflect.Descriptor instead.
func (*SetNetworkCredentialsResponse) ProtoMessage ¶
func (*SetNetworkCredentialsResponse) ProtoMessage()
func (*SetNetworkCredentialsResponse) ProtoReflect ¶
func (x *SetNetworkCredentialsResponse) ProtoReflect() protoreflect.Message
func (*SetNetworkCredentialsResponse) Reset ¶
func (x *SetNetworkCredentialsResponse) Reset()
func (*SetNetworkCredentialsResponse) String ¶
func (x *SetNetworkCredentialsResponse) String() string
type SetSmartMachineCredentialsRequest ¶
type SetSmartMachineCredentialsRequest struct {
Cloud *CloudConfig `protobuf:"bytes,1,opt,name=cloud,proto3" json:"cloud,omitempty"`
// contains filtered or unexported fields
}
func (*SetSmartMachineCredentialsRequest) Descriptor
deprecated
func (*SetSmartMachineCredentialsRequest) Descriptor() ([]byte, []int)
Deprecated: Use SetSmartMachineCredentialsRequest.ProtoReflect.Descriptor instead.
func (*SetSmartMachineCredentialsRequest) GetCloud ¶
func (x *SetSmartMachineCredentialsRequest) GetCloud() *CloudConfig
func (*SetSmartMachineCredentialsRequest) ProtoMessage ¶
func (*SetSmartMachineCredentialsRequest) ProtoMessage()
func (*SetSmartMachineCredentialsRequest) ProtoReflect ¶
func (x *SetSmartMachineCredentialsRequest) ProtoReflect() protoreflect.Message
func (*SetSmartMachineCredentialsRequest) Reset ¶
func (x *SetSmartMachineCredentialsRequest) Reset()
func (*SetSmartMachineCredentialsRequest) String ¶
func (x *SetSmartMachineCredentialsRequest) String() string
type SetSmartMachineCredentialsResponse ¶
type SetSmartMachineCredentialsResponse struct {
// contains filtered or unexported fields
}
func (*SetSmartMachineCredentialsResponse) Descriptor
deprecated
func (*SetSmartMachineCredentialsResponse) Descriptor() ([]byte, []int)
Deprecated: Use SetSmartMachineCredentialsResponse.ProtoReflect.Descriptor instead.
func (*SetSmartMachineCredentialsResponse) ProtoMessage ¶
func (*SetSmartMachineCredentialsResponse) ProtoMessage()
func (*SetSmartMachineCredentialsResponse) ProtoReflect ¶
func (x *SetSmartMachineCredentialsResponse) ProtoReflect() protoreflect.Message
func (*SetSmartMachineCredentialsResponse) Reset ¶
func (x *SetSmartMachineCredentialsResponse) Reset()
func (*SetSmartMachineCredentialsResponse) String ¶
func (x *SetSmartMachineCredentialsResponse) String() string
type UnimplementedProvisioningServiceServer ¶
type UnimplementedProvisioningServiceServer struct {
}
UnimplementedProvisioningServiceServer must be embedded to have forward compatible implementations.
func (UnimplementedProvisioningServiceServer) GetNetworkList ¶
func (UnimplementedProvisioningServiceServer) GetNetworkList(context.Context, *GetNetworkListRequest) (*GetNetworkListResponse, error)
func (UnimplementedProvisioningServiceServer) GetSmartMachineStatus ¶
func (UnimplementedProvisioningServiceServer) GetSmartMachineStatus(context.Context, *GetSmartMachineStatusRequest) (*GetSmartMachineStatusResponse, error)
func (UnimplementedProvisioningServiceServer) SetNetworkCredentials ¶
func (UnimplementedProvisioningServiceServer) SetNetworkCredentials(context.Context, *SetNetworkCredentialsRequest) (*SetNetworkCredentialsResponse, error)
func (UnimplementedProvisioningServiceServer) SetSmartMachineCredentials ¶
func (UnimplementedProvisioningServiceServer) SetSmartMachineCredentials(context.Context, *SetSmartMachineCredentialsRequest) (*SetSmartMachineCredentialsResponse, error)
type UnsafeProvisioningServiceServer ¶
type UnsafeProvisioningServiceServer interface {
// contains filtered or unexported methods
}
UnsafeProvisioningServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ProvisioningServiceServer will result in compilation errors.